aboutsummaryrefslogtreecommitdiffstats
path: root/camel/providers/mbox/camel-mbox-folder.h
diff options
context:
space:
mode:
authorbertrand <bertrand@helixcode.com>2000-01-20 11:02:13 +0800
committerBertrand Guiheneuf <bertrand@src.gnome.org>2000-01-20 11:02:13 +0800
commitde8e7223eac6c40b10d2a095210d2120aa97fa55 (patch)
tree1799dfad05eefa22a2f945492048499e897d10db /camel/providers/mbox/camel-mbox-folder.h
parent5b0a9fa89ef44fb96f12bffca3a3f1169d4b272d (diff)
downloadgsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar.gz
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar.bz2
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar.lz
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar.xz
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.tar.zst
gsoc2013-evolution-de8e7223eac6c40b10d2a095210d2120aa97fa55.zip
implemented.
2000-01-19 bertrand <bertrand@helixcode.com> * camel/providers/mbox/camel-mbox-folder.c (_get_message_count): implemented. * camel/providers/mbox/camel-mbox-summary.c (camel_mbox_save_summary): (camel_mbox_load_summary): save/load the next uid. * camel/providers/mbox/camel-mbox-parser.c (camel_mbox_parse_file): Compute the next available uid. * camel/providers/mbox/camel-mbox-folder.c (_create): (_check_get_or_maybe_generate_summary_file): Set and use the next_uid field properly. * camel/providers/mbox/camel-mbox-summary.h: added an extra field to store the next available uid. * camel/providers/mbox/camel-mbox-folder.c (_check_get_or_maybe_generate_summary_file): routine called when the folder is opened. Reads or creates the summary file. (_create): initialize the internal summary structure. (_close): save the summary file on closing. (_init_with_store): initialize mbox specific folder members. svn path=/trunk/; revision=1597
Diffstat (limited to 'camel/providers/mbox/camel-mbox-folder.h')
-rw-r--r--camel/providers/mbox/camel-mbox-folder.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/camel/providers/mbox/camel-mbox-folder.h b/camel/providers/mbox/camel-mbox-folder.h
index 1f010ce605..0923d28d2e 100644
--- a/camel/providers/mbox/camel-mbox-folder.h
+++ b/camel/providers/mbox/camel-mbox-folder.h
@@ -35,6 +35,8 @@ extern "C" {
#include <gtk/gtk.h>
#include "camel-folder.h"
+#include "camel-mbox-summary.h"
+
/* #include "camel-store.h" */
#define CAMEL_MBOX_FOLDER_TYPE (camel_mbox_folder_get_type ())
@@ -46,9 +48,12 @@ extern "C" {
typedef struct {
CamelFolder parent_object;
- gchar *folder_file_path; /* contains the messages */
- gchar *folder_dir_path; /* contains the subfolders */
- GArray *uid_array;
+ gchar *folder_file_path; /* contains the messages */
+ gchar *summary_file_path; /* contains the messages summary */
+ gchar *folder_dir_path; /* contains the subfolders */
+
+ CamelMboxSummary *summary; /* internal summary object */
+ GList *uid_array;
} CamelMboxFolder;